@@ -132,7 +132,7 @@ def stats_fmri(corrs, fisherz=True, permutation=False, iter=5000):
 
     if fisherz is True:
 
-        zs = 0.5 * np.log(1+rs)/(1-rs)
+        zs = 0.5 * np.log((1+rs)/(1-rs))
 
     # calculate the statistical results
     for i in range(n_x):
@@ -370,4 +370,4 @@ def stats_stpsfmri(corrs1, corrs2, fisherz=True, permutation=False, iter=5000):
                 if permutation == True:
                     stats[i, j, k, 1] = permutation_test(zs1[:, i, j, k], zs2[:, i, j, k], iter=iter)
 
-    return stats
+    return stats
\ No newline at end of file
